ATSAMx7x HAL - Hardware Abstraction Layer for the Microchip SAM E70/S70/V70/V71 (rev. B) MCUs
This crate is a non-exhaustive abstraction layer of the peripherals available on the Microchip SAM E70/S70/V70/V71 MCUs. Only the B-revision is supported.
Where able, hardware state is tracked by the type system and does not incur run-time overhead.
Examples for most implemented peripherals can be found in the git repository, under boards/.
Getting Started
After system start, the device’s wathdog is active, and will trigger a
system reset after about ~15 seconds. Additionally, before any work
can be done, the clock hierarchy must be configured, because it is
upstream of all other peripherals. Refer to clocks.
References
Any and all references to figures, pages and sections in this crate (both in documentation and source) refer to the complete datasheet of the SAM E70/S70/V70/V71 family of MCUs. The datasheet (DS60001527F) is available via Microchip (fetched 2022-08-04).
Re-exports
pub use embedded_hal as ehal;pub use fugit;pub use nb;pub use atsamv71q21b as pac;
Modules
- afec
- Analog Front-End Controller (AFEC; i.e., ADC)
- can
- This module provides target specific integration with the
mcancrate. - clocks
- Clock hierarchy configuration
- efc
- Flash controller configuration
- generics
- Crate generics
- pio
- Parallel Input/Output Controller
- pwm
- PWM (Pulse-width modulation)
- rtt
- Real-Time Timer (RTT)
- serial
- Serial communication peripherals
- tc
- Timer Counter (TC)
- usb
- Universal Serial Bus (USB)
- watchdog
- Watchdog timer configuration.